@@ -4,7 +4,7 @@ from ._schema_base import SchemaBase
 class Alter(SchemaBase):
 
     def alter(self, *items: str):
-        self.schema_collector.alter(*items)
+        self.collector.alter(*items)
         return self
 
     def build_alter(self, data):
