@@ -40,7 +40,7 @@ class Base:
 
     def __init__(self):
         self._lexer = lex.lex(module=self)
-        self._parser = yacc.yacc(module=self, start=self._start, debug=False)
+        self._parser = yacc.yacc(module=self, start=self._start, debug=True)
 
     def parse(self, s: str, ctx: Ctx):
         self.provider = Provider(ctx)
@@ -56,6 +56,8 @@ class Base:
         # do not escape information_schema as identifier
         if item == 'information_schema':
             return item
+        elif item == 'EXCLUDED':
+            return item
         else:
             return utils._quote_ident(item)
 
