@@ -1,15 +1,14 @@
 import json
 from ._base import _rule
-from .field import Field
-from .operators.comma import Comma
-from .operators.equal import Equal
+from .expr import Expr
 from windyquery.provider._base import JSONB
 from windyquery.utils import unquote_literal
 
 
-class Update(Field, Comma, Equal):
-    reserved = {**Field.reserved, **Comma.reserved, **Equal.reserved}
-    tokens = Field.tokens + Comma.tokens + Equal.tokens
+class Update(Expr):
+    reserved = {**Expr.reserved, }
+    tokens = Expr.tokens
+    precedence = Expr.precedence
 
     # rules
     _start = 'updates'
@@ -22,7 +21,7 @@ class Update(Field, Comma, Equal):
     def p_updates_comma_update(self, p):
         p[0] = self.provider.new_glue(p[1], p[3]).separator(', ')
 
-    @_rule('''update : field EQ field''')
+    @_rule('''update : field EQ expr''')
     def p_update(self, p):
         if p[2] == '=' and p[1].kind == JSONB:
             jsonbCol = p[1].path[0]
